@@ -16,7 +16,7 @@ WAConfig *WAConfig::self()
 }
 
 WAConfig::WAConfig(  )
-  : KConfigSkeleton( TQString::fromLatin1( "wlassistantrc" ) )
+  : TDEConfigSkeleton( TQString::fromLatin1( "wlassistantrc" ) )
 {
   mSelf = this;
 }
